# Choam

Python enviroment manager based around making depedency management, and publication easier.

## Snippets
___
The most useful snippets of `Choam`

#### To create a new project
`$ choam new <project_name>`

#### To initialize a project in the current directory
`$ choam init <project_name>`

#### Add required dependency
`$ choam add <dependency_name>`

#### Install required dependencies of an existing project
`$ choam install`

#### Find all required dependencies and update `Choam.toml` accordingly
`$ choam find-dependencies`

#### Setup config files for publication to PyPi
`$ choam setup`

#### Start publication to PyPi
`$ choam publish`

#### Run project entrypoint
`$ choam run <optional:relative_path>`
___

### This project is structured with [Choam](https://github.com/cowboycodr/choam)